
import React from 'react';
import { motion } from 'framer-motion';
import { Button } from '@/components/ui/button';
import { Input } from '@/components/ui/input';
import { Textarea } from '@/components/ui/textarea';
import { Label } from '@/components/ui/label';
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from '@/components/ui/select';
import { Checkbox } from '@/components/ui/checkbox';
import { useToast } from '@/components/ui/use-toast';
import { Mail, Phone, MapPin, Send } from 'lucide-react';

const ContactSection = () => {
  const { toast } = useToast();

  const handleSubmit = (e) => {
    e.preventDefault();
    toast({
      title: "Mesajınız Gönderildi!",
      description: "En kısa sürede size geri dönüş yapacağız.",
      variant: "success",
      duration: 5000,
    });
    e.target.reset();
  };

  return (
    <section id="contact" className="py-16 md:py-24 bg-gradient-to-b from-purple-700 to-indigo-800">
      <div className="container mx-auto px-4">
        <motion.h2
          initial={{ opacity: 0, y: 20 }}
          whileInView={{ opacity: 1, y: 0 }}
          viewport={{ once: true }}
          transition={{ duration: 0.6 }}
          className="text-4xl md:text-5xl font-bold text-center text-yellow-400 mb-16"
        >
          Bizimle İletişime Geçin
        </motion.h2>
        <div className="grid md:grid-cols-2 gap-12 items-start">
          <motion.div 
            className="space-y-8"
            initial={{ opacity: 0, x: -30 }}
            whileInView={{ opacity: 1, x: 0 }}
            viewport={{ once: true }}
            transition={{ duration: 0.7 }}
          >
            <h3 className="text-3xl font-semibold text-white mb-4">Satış Ekibimize Ulaşın</h3>
            <p className="text-white/80 text-lg leading-relaxed mb-6">
              PedalReklam ile markanızı daha hızlı ve görünür şekilde tanıtın. Yenilikçi reklam modellerimiz, yüksek etkileşim oranı, dikkat çekici reklam tasarımlarımız ve daha fazlasını keşfedin. Projeniz hakkında konuşmak ve size özel çözümler üretmek için sabırsızlanıyoruz!
            </p>
            <div className="space-y-4">
              <a href="mailto:info@pedalreklam.com" className="flex items-center text-lg text-white/90 hover:text-yellow-400 transition-colors group">
                <Mail size={24} className="mr-3 text-yellow-400 transition-transform duration-300 group-hover:scale-110" />
                info@pedalreklam.com
              </a>
              <a href="tel:+905551234567" className="flex items-center text-lg text-white/90 hover:text-yellow-400 transition-colors group">
                <Phone size={24} className="mr-3 text-yellow-400 transition-transform duration-300 group-hover:scale-110" />
                +90 555 123 45 67
              </a>
              <div className="flex items-start text-lg text-white/90 group">
                <MapPin size={24} className="mr-3 mt-1 text-yellow-400 transition-transform duration-300 group-hover:scale-110 flex-shrink-0" />
                <span>Örnek Mah. Bisiklet Sok. No:123, Reklam Plaza, Bursa, Türkiye</span>
              </div>
            </div>
            <div className="mt-8 w-full h-64 rounded-xl overflow-hidden shadow-xl border-2 border-yellow-400/30">
              <img  class="w-full h-full object-cover" alt="Modern office interior with people working" src="https://images.unsplash.com/photo-1551649081-39f820bb2d3e" />
            </div>
          </motion.div>

          <motion.form
            onSubmit={handleSubmit}
            className="space-y-5 p-8 bg-white/10 backdrop-blur-lg rounded-2xl shadow-xl border border-white/20"
            initial={{ opacity: 0, x: 30 }}
            whileInView={{ opacity: 1, x: 0 }}
            viewport={{ once: true }}
            transition={{ duration: 0.7 }}
          >
            <div className="grid grid-cols-1 sm:grid-cols-2 gap-5">
              <div>
                <Label htmlFor="contact_company_name" className="text-yellow-400 font-medium">Firma İsmi</Label>
                <Input id="contact_company_name" name="company_name" type="text" placeholder="Firma Adınız" className="bg-white/20 border-white/30 text-white placeholder:text-white/60 focus:border-yellow-400 focus:ring-yellow-400 mt-1" />
              </div>
              <div>
                <Label htmlFor="contact_full_name" className="text-yellow-400 font-medium">Yetkili İsmi</Label>
                <Input id="contact_full_name" name="full_name" type="text" placeholder="Adınız Soyadınız" required className="bg-white/20 border-white/30 text-white placeholder:text-white/60 focus:border-yellow-400 focus:ring-yellow-400 mt-1" />
              </div>
            </div>
            <div className="grid grid-cols-1 sm:grid-cols-2 gap-5">
              <div>
                <Label htmlFor="contact_phone" className="text-yellow-400 font-medium">Telefon Numarası</Label>
                <Input id="contact_phone" name="phone" type="tel" placeholder="05XX XXX XX XX" required className="bg-white/20 border-white/30 text-white placeholder:text-white/60 focus:border-yellow-400 focus:ring-yellow-400 mt-1" />
              </div>
              <div>
                <Label htmlFor="contact_email" className="text-yellow-400 font-medium">E-Posta</Label>
                <Input id="contact_email" name="email" type="email" placeholder="ornek@firma.com" required className="bg-white/20 border-white/30 text-white placeholder:text-white/60 focus:border-yellow-400 focus:ring-yellow-400 mt-1" />
              </div>
            </div>
            <div>
              <Label htmlFor="contact_route" className="text-yellow-400 font-medium">İlgilendiğiniz Güzergah</Label>
              <Input id="contact_route" name="route" type="text" placeholder="Hangi güzergahlarla ilgileniyorsunuz?" className="bg-white/20 border-white/30 text-white placeholder:text-white/60 focus:border-yellow-400 focus:ring-yellow-400 mt-1" />
            </div>
            <div>
              <Label htmlFor="contact_budget" className="text-yellow-400 font-medium">Reklam Bütçeniz</Label>
              <Select name="budget">
                <SelectTrigger className="w-full bg-white/20 border-white/30 text-white placeholder:text-white/60 focus:border-yellow-400 focus:ring-yellow-400 mt-1">
                  <SelectValue placeholder="Bir bütçe aralığı seçin" />
                </SelectTrigger>
                <SelectContent className="bg-purple-700 text-white border-purple-600">
                  <SelectItem value="<5000">5.000 TL Altı</SelectItem>
                  <SelectItem value="5000-15000">5.000 TL - 15.000 TL</SelectItem>
                  <SelectItem value="15000-30000">15.000 TL - 30.000 TL</SelectItem>
                  <SelectItem value=">30000">30.000 TL Üzeri</SelectItem>
                  <SelectItem value="belirsiz">Belirsiz / Görüşmek İstiyorum</SelectItem>
                </SelectContent>
              </Select>
            </div>
            <div>
              <Label htmlFor="contact_message" className="text-yellow-400 font-medium">Mesajınız</Label>
              <Textarea id="contact_message" name="message" placeholder="Eklemek istedikleriniz..." rows={3} className="bg-white/20 border-white/30 text-white placeholder:text-white/60 focus:border-yellow-400 focus:ring-yellow-400 mt-1" />
            </div>
            <div className="flex items-center space-x-2">
              <Checkbox id="contact_terms" name="terms" required className="border-yellow-400 data-[state=checked]:bg-yellow-400 data-[state=checked]:text-purple-700" />
              <Label htmlFor="contact_terms" className="text-sm text-white/70 font-normal">
                Bu formu göndererek <a href="#" className="underline hover:text-yellow-300">Gizlilik Politikamızı</a> ve <a href="#" className="underline hover:text-yellow-300">KVKK Aydınlatma Metnini</a> okuduğumu ve anladığımı kabul ediyorum.
              </Label>
            </div>
            <Button type="submit" size="lg" className="w-full bg-gradient-to-r from-yellow-400 to-orange-500 text-purple-900 font-bold hover:from-yellow-500 hover:to-orange-600 transition-all duration-300 transform hover:scale-105 shadow-xl py-3 text-lg rounded-full group">
              Mesajı Gönder
              <Send size={20} className="ml-2 transition-transform duration-300 group-hover:translate-x-1" />
            </Button>
          </motion.form>
        </div>
      </div>
    </section>
  );
};

export default ContactSection;
